## 0.0.65

This new version introduces several enhancements to the blog assistant CLI and blogging prompts, adds token budgeting for different models in the chatbot, and updates blogging and Patreon notebooks. A new notebook for semantic line breaks has also been added.

### New Features

- Blogging and Patreon notebooks have been updated with new code cells and existing ones have been improved. A new notebook, sembr.ipynb, has been added with code for semantic line breaks. These changes improve the functionality and expand the capabilities of the notebooks (a34a02) (Eric Ma)
- Token budgeting for different models has been added to the chatbot. This feature allows for more flexible token budgeting depending on the model used (cc7ab8) (Eric Ma)
- Several enhancements have been made to the blog assistant CLI and blogging prompts. The `summarize_and_tag` function has been renamed to `summarize` and now also returns the blog title. A new `social_media` function has been added to generate social media posts for LinkedIn, Patreon, and Twitter. The `blog_tagger_and_summarizer` prompt has been renamed to `blog_title_tags_summary` and now also returns the blog title. New prompts `compose_linkedin_post`, `compose_patreon_post`, and `compose_twitter_post` have been added to generate social media posts. A new `BlogInformation` model has been added to represent blog information (453e5d) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
